@@ -8,6 +8,7 @@
 
 import os
 import sys
+import glob
 import matplotlib
 
 from scipy import *
@@ -46,6 +47,9 @@ def plot_bf_dist(bf_filename, settings_filename, output_dir,
                           settings_filename=settings_filename)
     settings = sashimi_obj.settings
 
+    # Setup the figure
+    sashimi_obj.setup_figure()
+
     # Matrix of bayes factors and delta psi pairs
     bfs_and_deltas = []
     for event in data:
@@ -110,7 +114,8 @@ def plot_event(event_name, pickle_dir, settings_filename,
     genes_filename = os.path.join(pickle_dir,
                                   "genes_to_filenames.shelve")
 
-    if not os.path.isfile(genes_filename):
+    # Check that file basename exists 
+    if len(glob.glob("%s*" %(genes_filename))) == 0:
         raise Exception, "Cannot find file %s. Are you sure the events " \
               "were indexed with the latest version of index_gff.py?" \
               %(genes_filename)
@@ -137,10 +142,10 @@ def plot_insert_len(insert_len_filename,
     
     sashimi_obj = Sashimi(plot_name, output_dir,
                           settings_filename=settings_filename)
-
     settings = sashimi_obj.settings
     num_bins = settings["insert_len_bins"]
     output_filename = sashimi_obj.output_filename
+    sashimi_obj.setup_figure()
     s = plt.subplot(1, 1, 1)
     
     print "Plotting insert length distribution..."
